@@ -75,6 +75,8 @@ class Package(object):
             ResultModel.instance().versionHistory += "* dependency :" + str(dependency)
 
     def excommand(self, cmd):
+        if cmd.startswith("flutter"):
+            cmd = "export PUB_HOSTED_URL=https://pub.flutter-io.cn;export FLUTTER_STORAGE_BASE_URL=https://storage.flutter-io.cn;" + cmd
         returnCode, content = self.shell.excommand_until_done(cmd)
         if returnCode > 0:
             self.result.returnError("执行命令：" + str(cmd) + "发生错误，错误原因：" + str(content))
